/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 *  oafd: OAF CORBA dameon.
 *
 *  Copyright (C) 2000 Eazel, Inc.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this library; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Authors: Mathieu Lacage <mathieu@eazel.com>
 *
 */

#ifndef OBJECT_DIRECTORY_CONFIG_FILE_H
#define OBJECT_DIRECTORY_CONFIG_FILE_H

#include <tree.h> /* gnome-xml */

#define SERVER_CONFIG_FILE "/bonobo-activation/bonobo-activation-config.xml"

/* loads the information from oaf configuration file
   in $sysconfdir/oaf/oaf-conf.xml.
*/
char *object_directory_load_config_file (void);

#endif /* OBJECT_DIRECTORY_CONFIG_FILE_H */
